==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebValuesChangeDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebValuesChangeDetailDescription } from "./WebValuesChangeDetailDescription";
/**
 * @hidden
 */
var WebValuesChangeDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebValuesChangeDetailDescriptionMetadata, _super);
    function WebValuesChangeDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebValuesChangeDetailDescriptionMetadata.b = function (a) {
        if (WebValuesChangeDetailDescriptionMetadata.a == null) {
            WebValuesChangeDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebValuesChangeDetailDescriptionMetadata.c(WebValuesChangeDetailDescriptionMetadata.a);
        }
        if (a.k(WebValuesChangeDetailDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebValuesChangeDetailDescriptionMetadata.a);
        WebPivotValueDescriptionMetadata.d(a);
    };
    WebValuesChangeDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ValuesChangeDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Values", "Array:WebPivotValueDescription:PivotValue");
    };
    WebValuesChangeDetailDescriptionMetadata.d = function (a) {
        WebValuesChangeDetailDescriptionMetadata.b(a);
        a.ad("WebValuesChangeDetail", function () { return new WebValuesChangeDetailDescription(); });
        a.ac("WebValuesChangeDetail", WebValuesChangeDetailDescriptionMetadata.a);
    };
    WebValuesChangeDetailDescriptionMetadata.$t = markType(WebValuesChangeDetailDescriptionMetadata, 'WebValuesChangeDetailDescriptionMetadata');
    WebValuesChangeDetailDescriptionMetadata.a = null;
    return WebValuesChangeDetailDescriptionMetadata;
}(Base));
export { WebValuesChangeDetailDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebValuesChangeDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebValuesChangeDetailDescription } from "./WebValuesChangeDetailDescription";
/**
 * @hidden
 */
var WebValuesChangeDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebValuesChangeDetailDescriptionMetadata, _super);
    function WebValuesChangeDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebValuesChangeDetailDescriptionMetadata.b = function (a) {
        if (WebValuesChangeDetailDescriptionMetadata.a == null) {
            WebValuesChangeDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebValuesChangeDetailDescriptionMetadata.c(WebValuesChangeDetailDescriptionMetadata.a);
        }
        if (a.k(WebValuesChangeDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebValuesChangeDetailDescriptionMetadata.a);
        WebPivotValueDescriptionMetadata.d(a);
    };
    WebValuesChangeDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ValuesChangeDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Values", "Array:WebPivotValueDescription:PivotValue");
    };
    WebValuesChangeDetailDescriptionMetadata.d = function (a) {
        WebValuesChangeDetailDescriptionMetadata.b(a);
        a.ae("WebValuesChangeDetail", function () { return new WebValuesChangeDetailDescription(); });
        a.ad("WebValuesChangeDetail", WebValuesChangeDetailDescriptionMetadata.a);
    };
    WebValuesChangeDetailDescriptionMetadata.$t = markType(WebValuesChangeDetailDescriptionMetadata, 'WebValuesChangeDetailDescriptionMetadata');
    WebValuesChangeDetailDescriptionMetadata.a = null;
    return WebValuesChangeDetailDescriptionMetadata;
}(Base));
export { WebValuesChangeDetailDescriptionMetadata };
